@@ -4,7 +4,7 @@ import time
 import logging
 from pythonagent.agent.internal import udp
 from pythonagent.agent.probes.havoc.havoc_constants import HAVOC_TYPES, EXPIRE_DURATION_MS, SIZE_OF_OBJECTS_BYTES, HAVOC_PROFILES_JSON
-#from pythonagent.agent.probes.havoc.custom_memory_stress import apply_memory_leak
+# from pythonagent.agent.probes.havoc.custom_memory_stress import apply_memory_leak
 from pythonagent.utils import get_current_timestamp_in_ms
 
 havoc_types = {
@@ -67,8 +67,7 @@ class NDNetHavocRequest(object):
             self.backendName = havoc_conf.backendName
 
         except Exception as e:
-            self.logger.warning("Problem in creating havoc object {} ".format(e))
-
+            self.logger.warning("Optional parameters not found {}".format(e))
 
 
 class NDNetHavocMonitor(object):
